# FastAPI

![tag](python)

FastApi est un module python qui permet de réaliser simplement des services webs.
Il est hautement asynchrone (contrairement à Flask) et doit donc être lancé via un serveur ASGI.

pour installer les dépendance

> pip install fastapi uvicorn

## uvicorn

Uvicorn est un serveur ASGI (Asynchronous Server Gateway Interface) ultra-rapide pour exécuter des applications FastAPI, Django ASGI, Starlette, etc.

Il est basé sur uvloop et httptools, ce qui le rend beaucoup plus rapide que les serveurs WSGI traditionnels comme Gunicorn (utilisé pour Flask et Django en mode classique).

Uvicorn permet de :
- Lancer un serveur ultra-rapide compatible ASGI.
- Gérer les WebSockets, les requêtes longues et le streaming de données.
- Exécuter des tâches asynchrones efficacement (grâce à async/await).
- Supporter HTTP/2 et WebSockets pour une meilleure performance réseau.

pour lancer une application si ton fichier principal s'appelle main.py, exécute :

> uvicorn main:app --reload

quelques options utiles

✅ Changer le port et l'hôte (exemple : écouter sur toutes les interfaces et le port 9000)

>uvicorn main:app --host 0.0.0.0 --port 9000

✅ Lancer plusieurs workers (avec Gunicorn + Uvicorn en production)

> gunicorn -w 4 -k uvicorn.workers.UvicornWorker main:app

✅ Activer HTTP/2 et WebSockets

> uvicorn main:app --http h2 --ws auto

## créer des apis simples


on peut tester les apis sur http://127.0.0.1:8000/docs ou http://127.0.0.1:8000/redoc

```python
from fastapi import FastAPI, Path
from datetime import datetime

app = FastAPI()

@app.get("/time", 
    summary="Obtenir l'heure actuelle", 
    description="Retourne l'heure du serveur sous format YYYY-MM-DD HH:MM:SS.")
async def get_time():
    return {"current_time": datetime.now().strftime("%Y-%m-%d %H:%M:%S")}

@app.get("/add_two/{number}")
async def add_two(number: int):
    return {"result": number + 2}


@app.get("/add_three/{number}", 
    summary="Ajoute 3 à un nombre",
    description="Retourne le chiffre ajouté de 3")
async def add_two(
    number: int = Path(..., title="Nombre à modifier", description="Un nombre entier qui sera augmenté de 3.", example=5)
):
    return {"result": number + 3}

if __name__ == "__main__":
    import uvicorn
    uvicorn.run(app, host="127.0.0.1", port=8000)
```

fastapi permet la génération de documentation swagger en automatique ce qui est très interessant

pour desactiver l'accès aux docs

> app = FastAPI(docs_url=None, redoc_url=None)

pour avoir des urls spécifiques aux docs

> app = FastAPI(docs_url='myurl_docs' , redoc_url='myurl_redoc')